@@ -5,7 +5,7 @@ use warnings;
 
 use parent qw(Tickit::Widget);
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 =head1 NAME
 
@@ -13,7 +13,7 @@ Tickit::Widget::Figlet - trivial wrapper around L<Text::FIGlet> for banner rende
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -45,6 +45,8 @@ a L<Text::FIGlet> instance and calls C< figify > for rendering into a window.
 =cut
 
 use Text::FIGlet;
+use Tickit::Utils qw(textwidth);
+use List::UtilsBy qw(max_by);
 use Tickit::Style;
 use constant WIDGET_PEN_FROM_STYLE => 1;
 
@@ -70,6 +72,9 @@ Named parameters:
 
 =item * path (optional) - path to load fonts from, will obey $ENV{FIGLIB} by default
 
+=item * align (optional) - horizontal alignment to apply to text, can be a number from 0..1 or
+the text 'left', 'right', 'centre' (or 'center')
+
 =back
 
 Returns the instance.
@@ -81,6 +86,7 @@ sub new {
 	my $text = delete $args{text};
 	my $font = delete $args{font};
 	my $path = delete $args{path};
+	my $align = delete $args{align};
 	my $self = $class->SUPER::new(%args);
 	$self->{figlet} = Text::FIGlet->new(
 		-f => $font,
@@ -90,6 +96,12 @@ sub new {
 			: (),
 		)
 	);
+	$align //= 0;
+	$align = 0 if $align eq 'left';
+	$align = 1 if $align eq 'right';
+	$align = 0.5 if $align eq 'center';
+	$align = 0.5 if $align eq 'centre';
+	$self->{align} = $align;
 	$self->{text} = $text;
 	$self
 }
@@ -108,10 +120,24 @@ sub render_to_rb {
 	chomp(my @lines = $self->figlet->figify(
 		-A => $self->text
 	));
+	{ # Strip any cruft from start/end so we can align properly
+		my ($pre) = sort { $a <=> $b } map /^( *)/ ? length($1) : 0, @lines;
+		if($pre) {
+			substr $_, 0, $pre, '' for @lines
+		}
+		my ($post) = sort { $a <=> $b } map /( *)$/ ? length($1) : 0, @lines;
+		if($post) {
+			substr $_, -$post, $post, '' for @lines
+		}
+	}
+	my ($max) = sort { $b <=> $a } map textwidth($_), @lines;
+	my ($pre, $alloc, $post) = Tickit::Utils::align($max, $self->window->cols, $self->align);
 	my $y = 0;
-	$rb->text_at($y++, 0, shift(@lines), $self->get_style_pen) while @lines;
+	$rb->text_at($y++, $pre, shift(@lines), $self->get_style_pen) while @lines;
 }
 
+sub align:method { shift->{align} }
+
 =head2 text
 
 Returns the current text to display. Pass a new string in to update the rendered text.
